windows: Rename init_windows to windows_init

Change-Id: Icdee1694b230d3c03075b840ec31450a236ab9e1
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/windows.c b/windows.c
index 762054a..c14386c 100644
--- a/windows.c
+++ b/windows.c
@@ -83,12 +83,12 @@
 	return 0;
 }
 /*
  * init_windows() - Initalise the window cache
  * @context:    The mbox context pointer
  *
  * Return:      0 on success otherwise negative
  */
-int init_windows(struct mbox_context *context)
+int windows_init(struct mbox_context *context)
 {
 	int i;
@@ -83,12 +83,12 @@
 }
 /*
- * init_windows() - Initalise the window cache
+ * windows_init() - Initalise the window cache
  * @context:    The mbox context pointer
  *